==> openGion7.0.1.4_dev.zip: uap/webapps/ge/db/DERBY/sql/install/01_TABLE/GE52S.sql <==
/****************************************************************************/
/* GE52 ( 帳票ﾚｲｱｳﾄﾃｰﾌﾞﾙ )                                                  */
/*                                                                          */
/* Created : 2017/07/18 12:28:34                                            */
/****************************************************************************/

CREATE TABLE GE52 (
   SYSTEM_ID        VARCHAR (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID   */
 , LISTID           VARCHAR (  10 )                 NOT NULL            /*  20 帳票ID   */
 , KBTEXT           VARCHAR (   1 )                 NOT NULL            /*  30 ﾃｷｽﾄ区分 */
 , CLM              VARCHAR (  30 )                 NOT NULL            /*  40 項目     */
 , SEQ              INTEGER             DEFAULT 0   NOT NULL            /*  50 順       */
 , START_POS        INTEGER             DEFAULT 0   NOT NULL            /*  60 開始位置 */
 , USE_LENGTH       VARCHAR (   9 )     DEFAULT '0' NOT NULL            /*  70 使用桁数 */
 , FGUSE            VARCHAR (   1 )                 NOT NULL            /*  80 使用ﾌﾗｸﾞ */
 , RELEASE_NOTES    VARCHAR ( 120 )                                     /*  90 ﾘﾘｰｽﾉｰﾄ  */
 , RDC_CODE         VARCHAR (  20 )                                     /* 100 設変番号 */
 , FGJ              VARCHAR (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET            VARCHAR (  14 )                                     /* 820 登録日時 */
 , PGSET            VARCHAR (  10 )                                     /* 830 作成PG   */
 , PGPSET           VARCHAR (  10 )                                     /* 840 作成親PG */
 , USRSET           VARCHAR (  10 )                                     /* 850 作成社員 */
 , DYUPD            VARCHAR (  14 )                                     /* 860 更新日時 */
 , PGUPD            VARCHAR (  10 )                                     /* 870 更新PG   */
 , PGPUPD           VARCHAR (  10 )                                     /* 880 更新親PG */
 , USRUPD           VARCHAR (  10 )                                     /* 890 更新者   */
);

==> openGion7.0.3.0_dev.zip: uap/webapps/ge/db/DERBY/sql/install/01_TABLE/GE52S.sql <==
/****************************************************************************/
/* GE52 ( 帳票ﾚｲｱｳﾄﾃｰﾌﾞﾙ )                                                  */
/*                                                                          */
/* Created : 2018/09/28 16:03:46                                            */
/****************************************************************************/

CREATE TABLE GE52 (
   SYSTEM_ID        VARCHAR (  10 )                 NOT NULL            /*  10 ｼｽﾃﾑID   */
 , LISTID           VARCHAR (  10 )                 NOT NULL            /*  20 帳票ID   */
 , KBTEXT           VARCHAR (   1 )                 NOT NULL            /*  30 ﾃｷｽﾄ区分 */
 , CLM              VARCHAR (  30 )                 NOT NULL            /*  40 項目     */
 , SEQ              INTEGER             DEFAULT 0   NOT NULL            /*  50 順       */
 , START_POS        INTEGER             DEFAULT 0   NOT NULL            /*  60 開始位置 */
 , USE_LENGTH       VARCHAR (   9 )     DEFAULT '0' NOT NULL            /*  70 使用桁数 */
 , FGUSE            VARCHAR (   1 )                 NOT NULL            /*  80 使用ﾌﾗｸﾞ */
 , RELEASE_NOTES    VARCHAR ( 120 )                                     /*  90 ﾘﾘｰｽﾉｰﾄ  */
 , RDC_CODE         VARCHAR (  20 )                                     /* 100 設変番号 */
 , FGJ              VARCHAR (   1 )     DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET            VARCHAR (  14 )                                     /* 820 登録日時 */
 , PGSET            VARCHAR (  10 )                                     /* 830 作成PG   */
 , PGPSET           VARCHAR (  10 )                                     /* 840 作成親PG */
 , USRSET           VARCHAR (  10 )                                     /* 850 作成者   */
 , DYUPD            VARCHAR (  14 )                                     /* 860 更新日時 */
 , PGUPD            VARCHAR (  10 )                                     /* 870 更新PG   */
 , PGPUPD           VARCHAR (  10 )                                     /* 880 更新親PG */
 , USRUPD           VARCHAR (  10 )                                     /* 890 更新者   */
);
